mysql.exceptions.server.Stack_Overrun_Need_More

Package mysql :: Package exceptions :: Module server :: Class Stack_Overrun_Need_More |
[hide private]
[frames] | no frames]

# Class Stack_Overrun_Need_More

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Stack_Overrun_Need_More

Thread stack overrun: %ld bytes used of a %ld byte stack, and %ld bytes needed. Use 'mysqld -O thread_stack=#' to specify a bigger stack.

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`